@@ -25,18 +25,21 @@ class SharedBackendConf(SharedBackendConfUtils):
     # Getters
     #
 
-    def isH2OReplEnabled(self):
-        return self._jconf.isH2OReplEnabled()
-
     def cloudName(self):
         return self._get_option(self._jconf.cloudName())
 
+    def isH2OReplEnabled(self):
+        return self._jconf.isH2OReplEnabled()
+
     def backendClusterMode(self):
         return self._jconf.backendClusterMode()
 
     def isProgressBarEnabled(self):
         return self._jconf.isProgressBarEnabled()
 
+    def isModelPrintAfterTrainingEnabled(self):
+        return self._jconf.isModelPrintAfterTrainingEnabled()
+
     def scalaIntDefaultNum(self):
         return self._jconf.scalaIntDefaultNum()
 
@@ -236,6 +239,14 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setProgressBarDisabled()
         return self
 
+    def setModelPrintAfterTrainingEnabled(self):
+        self._jconf.setModelPrintAfterTrainingEnabled()
+        return self
+
+    def setModelPrintAfterTrainingDisabled(self):
+        self._jconf.setModelPrintAfterTrainingDisabled()
+        return self
+
     def setDefaultNumReplSessions(self, value):
         self._jconf.setDefaultNumReplSessions(value)
         return self
@@ -348,14 +359,14 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setNodeNetworkMask(value)
         return self
 
-    def setStacktraceCollectorInterval(self, value):
-        self._jconf.setStacktraceCollectorInterval(value)
-        return self
-
     def setContextPath(self, value):
         self._jconf.setContextPath(value)
         return self
 
+    def setStacktraceCollectorInterval(self, value):
+        self._jconf.setStacktraceCollectorInterval(value)
+        return self
+
     def setFlowScalaCellAsyncEnabled(self):
         self._jconf.setFlowScalaCellAsyncEnabled()
         return self
